import { Layout } from '@/utils/routerHelper'

const { t } = useI18n()
/**
 * redirect: noredirect        当设置 noredirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'          设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    hidden: true              当设置 true 的时候该路由不会再侧边栏出现 如404，login等页面(默认 false)

    alwaysShow: true          当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式，
                              只有一个时，会将那个子路由当做根路由显示在侧边栏，
                              若你想不管路由下面的 children 声明的个数都显示你的根路由，
                              你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，
                              一直显示根路由(默认 false)

    title: 'title'            设置该路由在侧边栏和面包屑中展示的名字

    icon: 'svg-name'          设置该路由的图标

    noCache: true             如果设置为true，则不会被 <keep-alive> 缓存(默认 false)

    breadcrumb: false         如果设置为false，则不会在breadcrumb面包屑中显示(默认 true)

    affix: true               如果设置为true，则会一直固定在tag项中(默认 false)

    noTagsView: true          如果设置为true，则不会出现在tag中(默认 false)

    activeMenu: '/dashboard'  显示高亮的路由路径

    followAuth: '/dashboard'  跟随哪个路由进行权限过滤

    canTo: true               设置为true即使hidden为true，也依然可以进行路由跳转(默认 false)
  }
 **/
const remainingRouter: AppRouteRecordRaw[] = [
  {
    path: '/redirect',
    component: Layout,
    name: 'Redirect',
    children: [
      {
        path: '/redirect/:path(.*)',
        name: 'Redirect',
        component: () => import('@/views/Redirect/Redirect.vue'),
        meta: {}
      }
    ],
    meta: {
      hidden: true,
      noTagsView: true
    }
  },
  {
    path: '/',
    component: Layout,
    redirect: '/index',
    name: 'Home',
    meta: { title: '统计报表' },
    children: [
      {
        path: 'index',
        component: () => import('@/views/Home/Index.vue'),
        name: 'Index',
        meta: {
          title: t('router.home'),
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'channel',
        component: () => import('@/views/Home/channel.vue'),
        name: 'ChannelStatistics',
        meta: {
          title: '渠道统计',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'status',
        component: () => import('@/views/Home/status.vue'),
        name: 'StatusStatistics',
        meta: {
          title: '线索状态统计',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      }
    ]
  },
  {
    path: '/clue',
    component: Layout,
    redirect: '/clue',
    name: 'Clue',
    meta: { title: '线索管理' },
    children: [
      {
        path: 'pool',
        component: () => import('@/views/Clue/Pool/index.vue'),
        name: 'CluePool',
        meta: {
          title: '线索池',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'order',
        component: () => import('@/views/Clue/Order/index.vue'),
        name: 'ClueOrder',
        meta: {
          title: '成交管理',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'skill',
        component: () => import('@/views/Clue/Skill/index.vue'),
        name: 'Skill',
        meta: {
          title: '关键话术',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'setting',
        component: () => import('@/views/Clue/Set/index.vue'),
        name: 'ClueSetting',
        meta: {
          title: '通用配置',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      }
    ]
  },
  {
    path: '/schoolManagement',
    component: Layout,
    redirect: '/schoolManagement',
    name: 'SchoolManagement',
    meta: { title: '驾校管理' },
    children: [
      {
        path: 'school',
        component: () => import('@/views/SchoolManagement/School/index.vue'),
        name: 'School',
        meta: {
          title: '驾校',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'place',
        component: () => import('@/views/SchoolManagement/Place/index.vue'),
        name: 'Place',
        meta: {
          title: '场地',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'class',
        component: () => import('@/views/SchoolManagement/Class/index.vue'),
        name: 'Class',
        meta: {
          title: '班型',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      }
    ]
  },
  {
    path: '/miniMall',
    component: Layout,
    redirect: '/miniMall/product',
    name: 'MiniMall',
    meta: { title: '进销存' },
    children: [
      {
        path: 'product',
        component: () => import('@/views/MiniMall/Product/index.vue'),
        name: 'Product',
        meta: {
          title: '产品列表',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'purchase',
        component: () => import('@/views/MiniMall/Purchase/index.vue'),
        name: 'Purchase',
        meta: {
          title: '采购列表',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'inventory',
        component: () => import('@/views/MiniMall/Inventory/index.vue'),
        name: 'Inventory',
        meta: {
          title: '库存管理',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'mallSet',
        component: () => import('@/views/MiniMall/MallSet/index.vue'),
        name: 'MallSet',
        meta: {
          title: '通用配置',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'productAdd',
        component: () => import('@/views/MiniMall/Product/add.vue'),
        name: 'ProductAdd',
        meta: {
          title: '产品新增',
          icon: 'ep:home-filled',
          hidden: true,
          canTo: true,
          noCache: false,
          affix: true
        }
      },
      {
        path: 'productEdit',
        component: () => import('@/views/MiniMall/Product/add.vue'),
        name: 'ProductEdit',
        meta: {
          title: '产品修改',
          icon: 'ep:home-filled',
          hidden: true,
          canTo: true,
          noCache: false,
          affix: true
        }
      }
    ]
  },

  {
    path: '/basic',
    component: Layout,
    redirect: '/basic/',
    name: 'Basic',
    meta: { title: '基础设置' },
    children: [
      {
        path: 'library',
        component: () => import('@/views/Basic/Library/index.vue'),
        name: 'Library',
        meta: {
          title: '知识库',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'wxRobot',
        component: () => import('@/views/Basic/WxRobot/index.vue'),
        name: 'WxRobot',
        meta: {
          title: '微信机器人',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'dept',
        component: () => import('@/views/Basic/Dept/index.vue'),
        name: 'Dept',
        meta: {
          title: '部门',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'role',
        component: () => import('@/views/Basic/Role/index.vue'),
        name: 'Role',
        meta: {
          title: '角色',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'employee',
        component: () => import('@/views/Basic/User/index.vue'),
        name: 'Employee',
        meta: {
          title: '员工',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'generalSet',
        component: () => import('@/views/Basic/GeneralSet/index.vue'),
        name: 'GeneralSet',
        meta: {
          title: '通用配置',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      },
      {
        path: 'menu',
        component: () => import('@/views/Basic/Menu/index.vue'),
        name: 'menu',
        meta: {
          title: '菜单管理',
          icon: 'ep:home-filled',
          noCache: false,
          affix: true
        }
      }
    ]
  },

  {
    path: '/user',
    component: Layout,
    name: 'UserInfo',
    meta: {
      hidden: true
    },
    children: [
      {
        path: 'profile',
        component: () => import('@/views/Profile/Index.vue'),
        name: 'Profile',
        meta: {
          canTo: true,
          hidden: true,
          noTagsView: false,
          icon: 'ep:user',
          title: t('common.profile')
        }
      },
      {
        path: 'notify-message',
        component: () => import('@/views/system/notify/my/index.vue'),
        name: 'MyNotifyMessage',
        meta: {
          canTo: true,
          hidden: true,
          noTagsView: false,
          icon: 'ep:message',
          title: '我的站内信'
        }
      }
    ]
  },

  // {
  //   path: '/dict',
  //   component: Layout,
  //   name: 'dict',
  //   meta: {
  //     hidden: true
  //   },
  //   children: [
  //     {
  //       path: 'type/data/:dictType',
  //       component: () => import('@/views/system/dict/data/index.vue'),
  //       name: 'SystemDictData',
  //       meta: {
  //         title: '字典数据',
  //         noCache: true,
  //         hidden: true,
  //         canTo: true,
  //         icon: '',
  //         activeMenu: '/system/dict'
  //       }
  //     }
  //   ]
  // },

  {
    path: '/login',
    component: () => import('@/views/Login/Login.vue'),
    name: 'Login',
    meta: {
      hidden: true,
      title: t('router.login'),
      noTagsView: true
    }
  },
  {
    path: '/sso',
    component: () => import('@/views/Login/Login.vue'),
    name: 'SSOLogin',
    meta: {
      hidden: true,
      title: t('router.login'),
      noTagsView: true
    }
  },
  {
    path: '/403',
    component: () => import('@/views/Error/403.vue'),
    name: 'NoAccess',
    meta: {
      hidden: true,
      title: '403',
      noTagsView: true
    }
  },
  {
    path: '/404',
    component: () => import('@/views/Error/404.vue'),
    name: 'NoFound',
    meta: {
      hidden: true,
      title: '404',
      noTagsView: true
    }
  },
  {
    path: '/500',
    component: () => import('@/views/Error/500.vue'),
    name: 'Error',
    meta: {
      hidden: true,
      title: '500',
      noTagsView: true
    }
  }
]

export default remainingRouter
