// import { CrudSchema } from '@/hooks/web/useCrudSchemas'
import { dateFormatter } from '@/utils/formatTime'
// import * as MailAccountApi from '@/api/system/mail/account'

// 表单校验
export const rules = reactive({
  username: [required],
  password: [required],
  host: [required],
  port: [required],
  sslEnable: [required]
})

// const userList = await MailAccountApi.getSimpleMailAccountList()
const userList = []

// CrudSchema：https://doc.iocoder.cn/vue3/crud-schema/
const crudSchemas = reactive([
  {
    label: '线索名称',
    field: 'name',
    isSearch: true,
    isTable: true
  },
  {
    label: '联系方式',
    field: 'contact',
    isSearch: true,
    isTable: true
  },
  {
    label: '线索位置',
    field: 'address',
    isSearch: true,
    isTable: true,
    isForm: false
  },
  {
    label: '线索来源',
    field: 'resource',
    isSearch: true,
    isTable: true,
    search: {
      component: 'Select',
      api: () => userList,
      componentProps: {
        optionsAlias: {
          labelField: 'name',
          valueField: 'id'
        }
      }
    },
    form: {
      component: 'Select',
      api: () => userList,
      componentProps: {
        optionsAlias: {
          labelField: 'name',
          valueField: 'id'
        }
      }
    }
  },
  {
    label: '意向状态',
    field: 'intention',
    isSearch: true,
    isTable: true,
    table: {
      fixed: 'left'
    },
    search: {
      component: 'Select',
      api: () => userList,
      componentProps: {
        optionsAlias: {
          labelField: 'name',
          valueField: 'id'
        }
      }
    },
    form: {
      component: 'Select',
      api: () => userList,
      componentProps: {
        optionsAlias: {
          labelField: 'name',
          valueField: 'id'
        }
      }
    }
  },
  {
    label: '跟进人员',
    field: 'userId',
    isSearch: true,
    isTable: true,
    isForm: false,
    search: {
      component: 'Select',
      api: () => userList,
      componentProps: {
        optionsAlias: {
          labelField: 'name',
          valueField: 'id'
        }
      }
    }
  },
  {
    label: '下次跟进时间',
    field: 'nextTime',
    isSearch: true,
    isTable: true,
    isForm: false,
    formatter: dateFormatter,
    detail: {
      dateFormat: 'YYYY-MM-DD'
    },
    search: {
      component: 'DatePicker',
      componentProps: {
        type: 'daterange',
        format: 'YYYY-MM-DD',
        valueFormat: 'YYYY-MM-DD',
        startPlaceholder: '下次跟进时间',
        endPlaceholder: '下次跟进时间'
      }
    }
  },
  {
    label: '诉求',
    field: 'need',
    isTable: true,
    form: {
      component: 'Input',
      componentProps: {
        type: 'textarea'
      },
      colProps: {
        span: 24
      }
    }
  },
  {
    label: '最新跟进时间',
    field: 'latestFollowTime',
    isTable: true,
    isForm: false
  },
  {
    label: '创建时间',
    field: 'createTime',
    isSearch: true,
    isTable: true,
    table: {
      fixed: 'left'
    },
    formatter: dateFormatter,
    detail: {
      dateFormat: 'YYYY-MM-DD'
    },
    search: {
      component: 'DatePicker',
      componentProps: {
        type: 'daterange',
        format: 'YYYY-MM-DD',
        valueFormat: 'YYYY-MM-DD',
        startPlaceholder: '创建时间',
        endPlaceholder: '创建时间'
      }
    },
    form: {
      component: 'DatePicker',
      componentProps: {
        type: 'date',
        format: 'YYYY-MM-DD',
        valueFormat: 'YYYY-MM-DD',
        placeholder: '创建时间'
      }
    }
  },
  {
    label: '跟进记录',
    field: 'followRecord',
    isTable: true
  },
  {
    label: '备注',
    field: 'remark',
    isTable: true,
    form: {
      component: 'Editor',
      colProps: {
        span: 24
      }
    }
  }
])
export const { allSchemas } = useCrudSchemas(crudSchemas)
